@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Moo;
 use strictures 2;
@@ -108,13 +108,6 @@ has single => (
 );
 
 
-has verbose => (
-    is      => 'ro',
-    isa     => \&_invalid_boolean,
-    default => sub { 0 },
-);
-
-
 has opus => (
     is       => 'ro',
     init_arg => undef,
@@ -149,8 +142,7 @@ sub process {
     # Counter for the tracks seen
     my $i = 0;
 
-    print "Ngram analysis:\n\tNum\tReps\tPhrase\n"
-        if $self->verbose;
+    my $analysis = "Ngram analysis:\n\tNum\tReps\tPhrase\n";
 
     # Handle each track...
     for my $t ( $self->opus->tracks ) {
@@ -163,8 +155,7 @@ sub process {
         next unless @events && defined $track_channel;
 
         $i++;
-        print "$t $i. channel: $track_channel\n"
-            if $self->verbose;
+        $analysis .= "$t $i. channel: $track_channel\n";
 
         # Declare the notes to inspect
         my $text = '';
@@ -203,8 +194,7 @@ sub process {
             # Convert MIDI numbers to named notes.
             my $text = _convert($num);
 
-            printf "\t%d\t%d\t%s %s\n", $j, $phrase->{$p}, $num, $text
-                if $self->verbose;
+            $analysis .= sprintf "\t%d\t%d\t%s %s\n", $j, $phrase->{$p}, $num, $text;
 
             # If we are playing by weight, save the number of times the phrase is repeated
             if ( $self->weight ) {
@@ -216,6 +206,8 @@ sub process {
             }
         }
     }
+
+    return $analysis;
 }
 
 
@@ -225,10 +217,10 @@ sub populate {
     $self->score( _setup_midi( bpm => $self->bpm ) );
 
     my @phrases;
+    my $playback;
 
     if ( $self->weight ) {
-        print "Weighted playback:\n\tLoop\tChan\tPhrase\n"
-            if $self->verbose;
+        $playback = "Weighted playback:\n\tLoop\tChan\tPhrase\n";
 
         for my $channel ( sort { $a <=> $b } keys %{ $self->notes } ) {
             # Create a function that adds notes to the score
@@ -246,8 +238,7 @@ sub populate {
                     # Convert MIDI numbers to named notes.
                     my $text = _convert($choice);
 
-                    print "\t$n\t$channel\t$choice $text\n"
-                        if $self->verbose;
+                    $playback .= "\t$n\t$channel\t$choice $text\n";
 
                     # Add each chosen note to the score
                     for my $note ( split /\s+/, $choice ) {
@@ -265,8 +256,7 @@ sub populate {
     }
     else {
         my $type = $self->shuffle_phrases ? 'Shuffled' : 'Ordered';
-        print "$type playback:\n\tN\tChan\tPhrase\n"
-            if $self->verbose;
+        $playback = "$type playback:\n\tN\tChan\tPhrase\n";
 
         my $n = 0;
 
@@ -285,8 +275,7 @@ sub populate {
                 # Convert MIDI numbers to named notes.
                 my $text = _convert($phrase);
 
-                print "\t$n\t$channel\t$phrase $text\n"
-                    if $self->verbose;
+                $playback .= "\t$n\t$channel\t$phrase $text\n";
 
                 my @phrase = split /\s/, $phrase;
                 push @all, @phrase;
@@ -316,6 +305,8 @@ sub populate {
     }
 
     $self->score->synch(@phrases);
+
+    return $playback;
 }
 
 
@@ -406,7 +397,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -416,10 +407,9 @@ version 0.03
     size      => 3,
     patches   => [qw( 68 69 70 71 72 73 )],
     randpatch => 1,
-    verbose   => 1,
   );
-  $mng->process;
-  $mng->populate;
+  my $analysis = $mng->process;
+  my $playback = $mng->populate;
   $mng->write;
 
 =head1 DESCRIPTION
@@ -483,10 +473,6 @@ Boolean.  Shuffle the non-weighted phrases before playing them.  Default: 0
 
 Boolean.  Allow single occurrence ngrams.  Default: 0
 
-=head2 verbose
-
-Boolean.  Output progress print statements.
-
 =head2 opus
 
 The MIDI opus object.  Constructed at runtime.  Constructor argument if given
@@ -512,15 +498,15 @@ Create a new C<MIDI::Ngram> object.
 
 =head2 process()
 
-  $mng->process;
+  my $analysis = $mng->process;
 
-Find all ngram phrases.
+Find all ngram phrases and return the note analysis.
 
 =head2 populate()
 
-  $mng->populate;
+  my $playback = $mng->populate;
 
-Add notes to the MIDI score.
+Add notes to the MIDI score and return the playback notes.
 
 =head2 write()
 
